# Generated by Django 5.0.1 on 2024-03-03 09:00

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('request_filters', '0005_alter_filteredrequest_options_and_more'),
    ]

    operations = [
        migrations.AlterModelOptions(
            name='filteredrequest',
            options={'ordering': ['-created_at__date', '-created_at__time__hour', '-created_at__time__minute', '-created_at__time__second', 'filter_index'], 'permissions': (('see_chart', 'View Chart'),), 'verbose_name': 'Filtered Request', 'verbose_name_plural': 'Filtered Requests'},
        ),
    ]
