# Generated by Django 5.0.1 on 2024-03-03 10:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('request_filters', '0006_alter_filteredrequest_options'),
    ]

    operations = [
        migrations.AlterField(
            model_name='filter',
            name='filter_type',
            field=models.CharField(choices=[('IP', 'IP'), ('USER_AGENT', 'User Agent'), ('PATH', 'Path'), ('QUERY_STRING', 'Query String'), ('REFERER', 'Referer'), ('COUNTRY', 'Country'), ('METHOD', 'Method'), ('HEADER', 'Header')], default='IP', max_length=20, verbose_name='Filter Type'),
        ),
    ]
